From eca9f75406e4fd923c203ea19348497e39cc9450 Mon Sep 17 00:00:00 2001
From: Guennadi Liakhovetski <g.liakhovetski@gmx.de>
Date: Wed, 3 Jun 2009 11:30:29 +0200
Subject: [PATCH 18/38] ov772x: S_CROP must return actually configured geometry

V4L2 drivers are allowed to configure a geometry different than what has been
requested by the user with S_CROP, but then they have to adjust the input
rectangle accordingly. Fix ov772x to comply with this requirement.

Signed-off-by: Guennadi Liakhovetski <g.liakhovetski@gmx.de>
---
 drivers/media/video/ov772x.c |   10 ++++++++--
 1 files changed, 8 insertions(+), 2 deletions(-)

diff --git a/drivers/media/video/ov772x.c b/drivers/media/video/ov772x.c
index c0c549f..b720558 100644
--- a/drivers/media/video/ov772x.c
+++ b/drivers/media/video/ov772x.c
@@ -960,12 +960,18 @@ static int ov772x_set_crop(struct soc_camera_device *icd,
 {
 	struct i2c_client *client = to_i2c_client(to_soc_camera_control(icd));
 	struct ov772x_priv *priv = to_ov772x(client);
+	int ret;
 
 	if (!priv->fmt)
 		return -EINVAL;
 
-	return ov772x_set_params(client, &rect->width, &rect->height,
-				 priv->fmt->fourcc);
+	ret = ov772x_set_params(client, &rect->width, &rect->height,
+				priv->fmt->fourcc);
+	if (!ret) {
+		rect->left = 0;
+		rect->top = 0;
+	}
+	return ret;
 }
 
 static int ov772x_s_fmt(struct v4l2_subdev *sd, struct v4l2_format *f)
-- 
1.6.2.4

